Module scope

Module scope 

Structs

ChioScope
What a capability token authorizes.
ModelMetadata
Metadata describing the model executing a tool-bearing agent.
MonetaryAmount
A monetary amount with currency denomination.
PromptGrant
Authorization for retrieving a prompt by name.
ResourceGrant
Authorization for reading or subscribing to a resource.
ToolGrant
Authorization for a single tool on a single server.

Enums

Constraint
A constraint on tool parameters.
ContentReviewTier
Content review tier for outbound communication constraints.
ModelSafetyTier
Safety tier for model-routing constraints.
Operation
An operation that can be performed under a grant.
SqlOperationClass
Operation class for data-layer tool calls (SQL, document DB, etc.).