Structs
- Chio
Scope - What a capability token authorizes.
- Model
Metadata - Metadata describing the model executing a tool-bearing agent.
- Monetary
Amount - A monetary amount with currency denomination.
- Prompt
Grant - Authorization for retrieving a prompt by name.
- Resource
Grant - Authorization for reading or subscribing to a resource.
- Tool
Grant - Authorization for a single tool on a single server.
Enums
- Constraint
- A constraint on tool parameters.
- Content
Review Tier - Content review tier for outbound communication constraints.
- Model
Safety Tier - Safety tier for model-routing constraints.
- Operation
- An operation that can be performed under a grant.
- SqlOperation
Class - Operation class for data-layer tool calls (SQL, document DB, etc.).